@@ -2,11 +2,15 @@
 
 $LANG = array(
 
+'L_MENU'											=> 'Menü',
 'L_UNKNOWN_ERROR'									=> 'Unbekannter Fehler',
 'L_CONFIRM_DELETE'									=> 'Bestätigen Sie die Löschung?',
 'L_SAVE_FILE'										=> 'Speichern Sie die Datei',
 'L_SAVE_FILE_SUCCESSFULLY'							=> 'Datei erfolgreich gespeichert',
 'L_SAVE_FILE_ERROR'									=> 'Fehler beim Speichern der Datei für',
+'L_DELETE'											=> 'Slet',
+'L_DELETE_FILE' 				    				=> 'Slet fil',
+'L_DELETE_FOLDER'				   					=> 'Slet mappe',
 'L_SAVE_SUCCESSFUL'									=> 'Daten erflogreich gespeichert',
 'L_SAVE_ERR'										=> 'Fehler während des Dateispeicherns',
 'L_NO_ENTRY'										=> 'Datenzugriff verboten',
@@ -107,6 +111,8 @@ $LANG = array(
 'L_ARTICLE_TITLE_HTMLTAG'							=> 'Title-Tag Inhalte (optional)',
 'L_ARTICLE_CHAPO_HIDE'								=> 'verbergen',
 'L_ARTICLE_CHAPO_DISPLAY'							=> 'anzeigen',
+'L_ARTICLE'											=> 'artikel',
+'L_ARTICLE_ID'										=> 'ID',
 'L_AUTH_PAGE_TITLE'									=> 'Anmeldung',
 'L_LOGOUT_SUCCESSFUL'								=> 'Sie wurden erflogreich abgemeldet',
 'L_LOGIN_PAGE'										=> 'Administrator Anmeldung',
@@ -130,7 +136,6 @@ $LANG = array(
 'L_HIDE'											=> 'Verstecken',
 'L_OPTIONS'											=> 'Optionen',
 'L_FOR_SELECTION'									=> 'Aktion auswählen...',
-'L_DELETE'											=> 'Löschen',
 'L_CAT_APPLY_BUTTON'								=> 'Änderungen speichern',
 'L_CAT_UNKNOWN'										=> 'Unbekannte Kategorie',
 'L_EDITCAT_PAGE_TITLE'								=> 'Kategorieoptionen ändern',
@@ -224,7 +229,7 @@ $LANG = array(
 'L_ALL_DRAFTS'										=> 'Entwürfe',
 'L_ALL_AWAITING_MODERATION'							=> 'erwarten Moderation',
 'L_MEDIAS_DELETE_FOLDER'							=> 'Ordner löschen',
-'L_MEDIAS_DELETE_FOLDER_CONFIRM'					=> 'Ordner inkl. Inhalt löschen?',
+'L_MEDIAS_DELETE_FOLDER_CONFIRM'					=> 'Ordner inkl. Inhalt löschen %s?',
 'L_MEDIAS_NO_FILE'									=> 'Keine Datei(en)',
 'L_MEDIAS_FILENAME'									=> 'Dateiname',
 'L_MEDIAS_ADD_FILE'									=> 'Dateien hochladen',
@@ -276,7 +281,7 @@ $LANG = array(
 'L_CONFIG_VIEW_IMAGES'								=> 'Bildgröße (Breite x Höhe)',
 'L_CONFIG_VIEW_THUMBS'								=> 'Größe der Miniaturansicht (Breite x Höhe)',
 'L_CONFIG_VIEW_HOMESTATIC'							=> 'Eine statische Seite als Homepage verwenden',
-'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'					=> '<span class="alert">Achtung! Diese Seite ist inaktiv</span>',
+'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'					=> 'Achtung! Diese Seite ist inaktiv',
 'L_CONFIG_VIEW_PLUXML_RESSOURCES'					=> 'Themen von <a href="http://ressources.pluxml.org">ressources.pluxml.org</a> laden.',
 'L_CONFIG_VIEW_BYPAGE_FEEDS'						=> 'Anzahl der angezeigten Artikel/Kommentare im RSS Feed',
 'L_CONFIG_VIEW_FEEDS_HEADLINE'						=> 'Im RSS Feed nur Vorspann des Artikels zeigen',
@@ -287,16 +292,15 @@ $LANG = array(
 'L_CONFIG_HOMETEMPLATE'								=> 'Vorlage der Homepage',
 'L_CONFIG_ADVANCED_DESC'							=> 'Erweiterte Einstellungen',
 'L_CONFIG_ADVANCED_URL_REWRITE'						=> 'Adressweiterleitung aktivieren (URL rewrite)',
-'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'				=> '<span class="alert">Achtung! Es ist bereits eine .htaccess Datei im Grundverzeichnis von PluXml vorhanden. Diese Datei wird beim Aktivieren modifiziert.</span>',
+'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'				=> 'Achtung! Es ist bereits eine .htaccess Datei im Grundverzeichnis von PluXml vorhanden. Diese Datei wird beim Aktivieren modifiziert.',
 'L_CONFIG_ADVANCED_GZIP'							=> 'GZIP Kompression aktivieren',
 'L_CONFIG_ADVANCED_GZIP_HELP'						=> 'Komprimierung spart Bandreite, erhöht aber die Prozessorauslastung des Servers.',
 'L_CONFIG_ADVANCED_CAPCHA'							=> 'ANTI-SPAM Kontrolle aktivieren',
 'L_CONFIG_ADVANCED_ADMIN_KEY'						=> 'Adminschlüssel (private URLs)',
 'L_CONFIG_ADVANCED_KEY_HELP'						=> 'Feld leeren um neuen Schlüssel zu generieren',
-'L_CONFIG_ADVANCED_USERFOLDERS'						=> 'Für jeden Benutzer einen eigenen Daten- und Bildordner verwenden',
+'L_CONFIG_ADVANCED_USERFOLDERS'						=> 'Verwenden Sie unterschiedliche Medien Ordner für jeden Benutzer',
 'L_HELP_SLASH_END'									=> 'Schrägstrich (Slash) am Ende nicht vergessen!',
-'L_CONFIG_ADVANCED_PICS_FOLDER'						=> 'Bildordner',
-'L_CONFIG_ADVANCED_DOCS_FOLDER'						=> 'Datenordner',
+'L_CONFIG_ADVANCED_MEDIAS_FOLDER'					=> 'Medien-Speicherort (Ordner)',
 'L_CONFIG_ADVANCED_ARTS_FOLDER'						=> 'Artikelordner',
 'L_CONFIG_ADVANCED_COMS_FOLDER'						=> 'Kommentarordner',
 'L_CONFIG_ADVANCED_STATS_FOLDER'					=> 'Ordner für statische Seiten',
@@ -304,6 +308,7 @@ $LANG = array(
 'L_CONFIG_ADVANCED_PLUGINS_FOLDER'					=> 'Plugins Ordner',
 'L_CONFIG_ADVANCED_CONFIG_FOLDER'					=> 'Ort der Konfigurationsdateien (Ordner)',
 'L_CONFIG_ADVANCED_UPDATE'							=> 'Änderungen speichern',
+'L_CONFIG_CUSTOM_CSSADMIN_PATH'						=> 'Standort und den Namen der benutzerdefinierten CSS-Datei des Verwaltungsbereich (optional)',
 'L_CONFIG_BASE_CONFIG_TITLE'						=> 'Grundeinstellungen',
 'L_CONFIG_BASE_SITE_TITLE'							=> 'Titel der Website',
 'L_CONFIG_BASE_SITE_SLOGAN'							=> 'Untertitel/Beschreibung der Website',
@@ -437,7 +442,7 @@ $LANG = array(
 'L_MENU_CONFIG'										=> 'Konfiguration',
 'L_MENU_PROFIL_TITLE'								=> 'Mein Benutzerprofil verwalten',
 'L_MENU_PROFIL'										=> 'Mein Profil',
-'L_WARNING_INSTALLATION_FILE'						=> '<p class="warning">Die Datei install.php existiert noch im Grundverzeichnis von PluXml.<br />Sie sollten diese aus Sicherheitsgründen löschen.</p>',
+'L_WARNING_INSTALLATION_FILE'						=> 'Die Datei install.php existiert noch im Grundverzeichnis von PluXml.<br />Sie sollten diese aus Sicherheitsgründen löschen.',
 'L_USER_UNKNOWN'									=> 'Unbekannter Benutzer',
 'L_USER_LANG'										=> 'Spracher des Admins',
 'L_USER_MAIL'										=> 'E-Mail-Adresse',
