@@ -2,11 +2,15 @@
 
 $LANG = array(
 
+'L_MENU'													=> 'Menu',
 'L_UNKNOWN_ERROR'											=> 'Unknown error',
 'L_CONFIRM_DELETE'											=> 'Confirm the deletion?',
 'L_SAVE_FILE'												=> 'Save the file',
 'L_SAVE_FILE_SUCCESSFULLY'									=> 'File saved successfully',
 'L_SAVE_FILE_ERROR'											=> 'Error while saving file',
+'L_DELETE'													=> 'Delete',
+'L_DELETE_FILE' 				    						=> 'Delete file',
+'L_DELETE_FOLDER'				   							=> 'Delete folder',
 'L_SAVE_SUCCESSFUL'											=> 'Data was succesfully saved',
 'L_SAVE_ERR'												=> 'Error while saving data',
 'L_NO_ENTRY'												=> 'No entry',
@@ -107,6 +111,8 @@ $LANG = array(
 'L_ARTICLE_TITLE_HTMLTAG'									=> 'Title tag contents (optional)',
 'L_ARTICLE_CHAPO_HIDE'										=> 'hide',
 'L_ARTICLE_CHAPO_DISPLAY'									=> 'display',
+'L_ARTICLE'													=> 'article',
+'L_ARTICLE_ID'												=> 'Ident',
 'L_AUTH_PAGE_TITLE'											=> 'Authentication page',
 'L_LOGOUT_SUCCESSFUL'										=> 'Logout successful',
 'L_LOGIN_PAGE'												=> 'Login to administration',
@@ -137,7 +143,6 @@ $LANG = array(
 'L_NONE1'													=> 'none',
 'L_NONE2'													=> 'none',
 'L_FOR_SELECTION'											=> 'Selected items...',
-'L_DELETE'													=> 'Delete',
 'L_CAT_APPLY_BUTTON'										=> 'Change categories list',
 'L_CAT_UNKNOWN'												=> 'Unknown category',
 'L_EDITCAT_PAGE_TITLE'										=> 'Edit category options',
@@ -231,7 +236,7 @@ $LANG = array(
 'L_ALL_DRAFTS'												=> 'Drafts',
 'L_ALL_AWAITING_MODERATION'									=> 'Awaiting validation',
 'L_MEDIAS_DELETE_FOLDER'									=> 'Delete folder',
-'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Delete folder and its content ?',
+'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Delete folder %s and its content ?',
 'L_MEDIAS_NO_FILE'											=> 'No file',
 'L_MEDIAS_FILENAME'											=> 'File name',
 'L_MEDIAS_ADD_FILE'											=> 'Add file',
@@ -275,7 +280,7 @@ $LANG = array(
 'L_CONFIG_VIEW_IMAGES'										=> 'Image Size (width x height)',
 'L_CONFIG_VIEW_THUMBS'										=> 'Thumbnails size (width x height)',
 'L_CONFIG_VIEW_HOMESTATIC'									=> 'Use a static page as Homepage',
-'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> '<span class="alert">Warning: this page is inactive</span>',
+'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Warning: this page is inactive',
 'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Download themes at <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
 'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'N° of Articles or comments in the Rss feed',
 'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Only display headlines in the Rss article feed',
@@ -286,16 +291,15 @@ $LANG = array(
 'L_CONFIG_HOMETEMPLATE'										=> 'Template of the homepage',
 'L_CONFIG_ADVANCED_DESC'									=> 'Advanced configuration',
 'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'Enable url rewriting',
-'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> '<span class="alert">Warning: a .htaccess file already exists at your PluXml\'s installation root. Activating url rewriting will overwrite this file</span>',
+'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Warning: a .htaccess file already exists at your PluXml\'s installation root. Activating url rewriting will overwrite this file',
 'L_CONFIG_ADVANCED_GZIP'									=> 'Enable GZIP compression',
 'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Makes it possible to compress pages to save bandwidth, but could increase CPU usage',
 'L_CONFIG_ADVANCED_CAPCHA'									=> 'Enable anti spam-capcha',
 'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Administration key (private URLs)',
 'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Leave this field empty to rebuild key',
-'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Use separate Images and Documents folders for every user',
+'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Use separate medias folders for every user',
 'L_HELP_SLASH_END'											=> 'Don\'t forget the slash at the end',
-'L_CONFIG_ADVANCED_PICS_FOLDER'								=> 'Images (folder) location',
-'L_CONFIG_ADVANCED_DOCS_FOLDER'								=> 'Documents (folder) location',
+'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Medias (folder) location',
 'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Articles (folder) location',
 'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Comments (folder) location',
 'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Static page (folder) location',
@@ -303,6 +307,7 @@ $LANG = array(
 'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Plugins (folder) location',
 'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Configuration files (folder) location',
 'L_CONFIG_ADVANCED_UPDATE'									=> 'Save advanced configuration',
+'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Location and name of custom css file of the administration area (optional)',
 'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Basic configuration',
 'L_CONFIG_BASE_SITE_TITLE'									=> 'Site title',
 'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Subtitle / Site description',
@@ -436,7 +441,7 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Parameters',
 'L_MENU_PROFIL_TITLE'										=> 'Manage your user profiles',
 'L_MENU_PROFIL'												=> 'Profile',
-'L_WARNING_INSTALLATION_FILE'								=> '<p class="warning">install.php file can still be found at your PluXml root.<br />For security reasons, it is strongly recommended to delete it.</p>',
+'L_WARNING_INSTALLATION_FILE'								=> 'install.php file can still be found at your PluXml root.<br />For security reasons, it is strongly recommended to delete it.',
 'L_USER_UNKNOWN'											=> 'Unknown user',
 'L_USER_LANG'												=> 'Language used in administration',
 'L_USER_MAIL'												=> 'Email adress',
