@@ -2,11 +2,15 @@
 
 $LANG = array(
 
+'L_MENU'													=> 'Menu',
 'L_UNKNOWN_ERROR'											=> 'Errore sconosciuto',
 'L_CONFIRM_DELETE'											=> 'Confermare l\'eliminazione ?',
 'L_SAVE_FILE'												=> 'Salvare il file',
 'L_SAVE_FILE_SUCCESSFULLY'									=> 'File salvato con successo',
 'L_SAVE_FILE_ERROR'											=> 'Salvataggio del file per errore',
+'L_DELETE'													=> 'Cancella',
+'L_DELETE_FILE' 				    						=> 'Cancella il file',
+'L_DELETE_FOLDER'				   							=> 'Eliminare la cartella',
 'L_SAVE_SUCCESSFUL'											=> 'Dati salvati con successo',
 'L_SAVE_ERR'												=> 'Errore durante il salvataggio dei dati',
 'L_NO_ENTRY'												=> 'Accesso non consentito',
@@ -107,6 +111,8 @@ $LANG = array(
 'L_ARTICLE_TITLE_HTMLTAG'									=> 'Titolo contenuto tag (opzionale)',
 'L_ARTICLE_CHAPO_HIDE'										=> 'nascondere',
 'L_ARTICLE_CHAPO_DISPLAY'									=> 'mostrare',
+'L_ARTICLE'													=> 'articolo',
+'L_ARTICLE_ID'												=> 'ID',
 'L_AUTH_PAGE_TITLE'											=> 'Pagina di autenticazione',
 'L_LOGOUT_SUCCESSFUL'										=> 'Disconnessione avvenuta con successo',
 'L_LOGIN_PAGE'												=> 'Pannello di amministrazione',
@@ -129,7 +135,6 @@ $LANG = array(
 'L_HIDE'													=> 'Nascondi',
 'L_OPTIONS'													=> 'Opzioni',
 'L_FOR_SELECTION'											=> 'Se selezionati...',
-'L_DELETE'													=> 'Cancella',
 'L_CAT_APPLY_BUTTON'										=> 'Modifica la lista delle categorie',
 'L_CAT_UNKNOWN'												=> 'categoria sconosciuta',
 'L_EDITCAT_PAGE_TITLE'										=> 'Gestisci le opzioni delle categorie',
@@ -223,7 +228,7 @@ $LANG = array(
 'L_ALL_DRAFTS'												=> 'Bozze',
 'L_ALL_AWAITING_MODERATION'									=> 'In attesa di convalida',
 'L_MEDIAS_DELETE_FOLDER'									=> 'Cancella questa cartella',
-'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Vuoi cancellare la cartella e il suo contenuto ?',
+'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Vuoi cancellare la cartella %s e il suo contenuto ?',
 'L_MEDIAS_NO_FILE'											=> 'Nessun file',
 'L_MEDIAS_FILENAME'											=> 'Nome del file',
 'L_MEDIAS_ADD_FILE'											=> 'Aggiungi file',
@@ -275,7 +280,7 @@ $LANG = array(
 'L_CONFIG_VIEW_IMAGES'										=> 'Immagine Dimensioni (larghezza x altezza)',
 'L_CONFIG_VIEW_THUMBS'										=> 'Dimensione delle miniature (larghezza x altezza)',
 'L_CONFIG_VIEW_HOMESTATIC'									=> 'Usa una pagina statica come homepage',
-'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> '<span class="alert">Attenzione, questa pagina non è attiva</span>',
+'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Attenzione, questa pagina non è attiva',
 'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Scarica altri temi su <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
 'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'Numero di articoli/commenti visualizzati',
 'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Visualizzare solo la premessa degli articoli',
@@ -286,16 +291,15 @@ $LANG = array(
 'L_CONFIG_HOMETEMPLATE'										=> 'Modello della homepage',
 'L_CONFIG_ADVANCED_DESC'									=> 'Configurazione avanzata',
 'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'Abilita la riscrittura degli url',
-'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> '<span class="alert">Attenzione un file .htaccess è già presente alla radice di PluXml. Abilitando la riscrittura degli url questo file sarà modificato</span>',
+'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Attenzione un file .htaccess è già presente alla radice di PluXml. Abilitando la riscrittura degli url questo file sarà modificato',
 'L_CONFIG_ADVANCED_GZIP'									=> 'Abilita la compressione GZIP',
 'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Consente la compressione delle pagine per ridurre la banda utilizzata, ciò potrebbe richiedere un maggiore utilizzo del processore',
 'L_CONFIG_ADVANCED_CAPCHA'									=> 'Abilita il capcha anti-spam',
 'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Chiave di amministrazione (URL privati)',
 'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Svuota questo campo per rigenerare la chiave',
-'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Usare delle cartelle immagini e documenti diverse per ogni user',
+'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Usare delle cartelle medias diverse per ogni user',
 'L_HELP_SLASH_END'											=> 'Non dimenticare la slash alla fine',
-'L_CONFIG_ADVANCED_PICS_FOLDER'								=> 'Posizionamento delle immagini (cartella)',
-'L_CONFIG_ADVANCED_DOCS_FOLDER'								=> 'Posizionamento dei documenti (cartella)',
+'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Posizione media (cartella)',
 'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Posizionamento degli articoli(cartella)',
 'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Posizionamento dei commenti (cartella)',
 'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Posizionamento delle pagine statiche (cartella)',
@@ -303,6 +307,7 @@ $LANG = array(
 'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Posizionamento dei plugin (cartella)',
 'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Posizionamento dei file di configurazione (cartella)',
 'L_CONFIG_ADVANCED_UPDATE'									=> 'Modifica la configurazione avanzata',
+'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Ubicazione e nome del file CSS personalizzato dell\'area amministrazione (optional)',
 'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Configurazione base',
 'L_CONFIG_BASE_SITE_TITLE'									=> 'Titolo del sito',
 'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Sottotitolo/descrizione del sito',
@@ -436,7 +441,7 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Parametri',
 'L_MENU_PROFIL_TITLE'										=> 'Gestisci il profilo',
 'L_MENU_PROFIL'												=> 'Profilo',
-'L_WARNING_INSTALLATION_FILE'								=> '<p class="warning">Il file install.php è presente nella radice di PluXml.<br />Per motivi di sicurezza, è fortemente consigliata la cancellazione.</p>',
+'L_WARNING_INSTALLATION_FILE'								=> 'Il file install.php è presente nella radice di PluXml.<br />Per motivi di sicurezza, è fortemente consigliata la cancellazione.',
 'L_USER_UNKNOWN'											=> 'Utente sconosciuto',
 'L_USER_LANG'												=> 'Lingua usata nel pannello di amministrazione',
 'L_USER_MAIL'												=> 'Indirizzo email',
