@@ -2,11 +2,15 @@
 
 $LANG = array(
 
+'L_MENU'													=> 'Menu',
 'L_UNKNOWN_ERROR'											=> 'Onbekende fout',
 'L_CONFIRM_DELETE'											=> 'Bevestig de verwijdering ?',
 'L_SAVE_FILE'												=> 'Sla het bestand op',
 'L_SAVE_FILE_SUCCESSFULLY'									=> 'Bestand succesvol opgeslagen',
 'L_SAVE_FILE_ERROR'											=> 'Fout bij het ​​opslaan van het bestand voor',
+'L_DELETE'													=> 'Verwijderen',
+'L_DELETE_FILE' 				    						=> 'Bestand verwijderen',
+'L_DELETE_FOLDER'				   							=> 'Map verwijderen',
 'L_SAVE_SUCCESSFUL'											=> 'Gegevens succesvol opgeslagen',
 'L_SAVE_ERR'												=> 'Fout bij het opslaan van de gegevens',
 'L_NO_ENTRY'												=> 'Geen toegang',
@@ -107,6 +111,8 @@ $LANG = array(
 'L_ARTICLE_TITLE_HTMLTAG'									=> 'Title tag inhoud (optioneel)',
 'L_ARTICLE_CHAPO_HIDE'										=> 'verstoppen',
 'L_ARTICLE_CHAPO_DISPLAY'									=> 'tonen',
+'L_ARTICLE'													=> 'artikel',
+'L_ARTICLE_ID'												=> 'ID',
 'L_AUTH_PAGE_TITLE'											=> 'Aanmeldpagina',
 'L_LOGOUT_SUCCESSFUL'										=> 'U bent succesvol aangemeld',
 'L_LOGIN_PAGE'												=> 'Aanmelden in administratie',
@@ -116,7 +122,7 @@ $LANG = array(
 'L_ERR_WRONG_PASSWORD'										=> 'Login en/of wachtwoord ongeldig',
 'L_POWERED_BY'												=> 'Gegenereerd door <a href="http://www.pluxml.org">PluXml</a>',
 'L_CAT_TITLE'												=> 'Aanmaken en aanpassen van categorie?n',
-'L_CAT_LIST_ID'												=> 'Identifiant',
+'L_CAT_LIST_ID'												=> 'ID',
 'L_CAT_LIST_ACTIVE'											=> 'Actief',
 'L_CAT_LIST_NAME'											=> 'Naam categorie',
 'L_CAT_LIST_URL'											=> 'URL',
@@ -129,7 +135,6 @@ $LANG = array(
 'L_HIDE'													=> 'Onzichtbaar maken',
 'L_OPTIONS'													=> 'Opties',
 'L_FOR_SELECTION'											=> 'Met geselecteerde...',
-'L_DELETE'													=> 'Verwijderen',
 'L_CAT_APPLY_BUTTON'										=> 'Categorielijst aanpassen',
 'L_CAT_UNKNOWN'												=> 'onbekende categorie',
 'L_EDITCAT_PAGE_TITLE'										=> 'Categorie-opties aanpassen',
@@ -223,7 +228,7 @@ $LANG = array(
 'L_ALL_DRAFTS'												=> 'Concepten',
 'L_ALL_AWAITING_MODERATION'									=> 'In afwachting van de validatie',
 'L_MEDIAS_DELETE_FOLDER'									=> 'Map verwijderen',
-'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Map en inhoud van de map verwijderen ?',
+'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Map en inhoud van de map verwijderen %s ?',
 'L_MEDIAS_NO_FILE'											=> 'Geen bestand',
 'L_MEDIAS_FILENAME'											=> 'Naam bastand',
 'L_MEDIAS_ADD_FILE'											=> 'Bestand toevoegne',
@@ -275,7 +280,7 @@ $LANG = array(
 'L_CONFIG_VIEW_IMAGES'										=> 'Beeldformaat (breedte x hoogte)',
 'L_CONFIG_VIEW_THUMBS'										=> 'Grootte thumbnails (breedte x hoogte)',
 'L_CONFIG_VIEW_HOMESTATIC'									=> 'een statische pagina als verwelkomingspagina gebruiken',
-'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> '<span class="alert">Opgelet. Deze pagina is niet actief</span>',
+'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Opgelet. Deze pagina is niet actief',
 'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Nieuwe layouts downloaden op <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
 'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'Aantal artikels/commentaar in RSS feed',
 'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Korte samenvatting in RSS feed opnemen',
@@ -286,16 +291,15 @@ $LANG = array(
 'L_CONFIG_HOMETEMPLATE'										=> 'Template van de homepage',
 'L_CONFIG_ADVANCED_DESC'									=> 'Geavanceerde configuratie',
 'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'herschrijven van URLs aanzetten',
-'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> '<span class="alert">Opgepast. Er bestaat al een .htaccess bestand in de root van uw installatie. Door het inschakelen van URL herschrijven dit bestand zal worden gewijzigd</span>',
+'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Opgepast. Er bestaat al een .htaccess bestand in de root van uw installatie. Door het inschakelen van URL herschrijven dit bestand zal worden gewijzigd',
 'L_CONFIG_ADVANCED_GZIP'									=> 'GZIP compressie activeren',
 'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Compressie activeren zal het verbruik van uw bandbreedte naar beneden halen, maar kan uw processor wat meer belasten',
 'L_CONFIG_ADVANCED_CAPCHA'									=> 'Anti-spam CAPTCHA gebruiken',
 'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Code voor versleuteling gegevens (Prive URLs)',
 'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Maak dit veld leeg om een nieuwe sleutel te genereren',
-'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Een verschillende documenten- en afbeeldingenmap gebruiken voor elke gebruiker',
+'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Gebruik verschillende media map voor elke gebruiker',
 'L_HELP_SLASH_END'											=> 'vergeet de slash niet op het einde',
-'L_CONFIG_ADVANCED_PICS_FOLDER'								=> 'Locatie Afbeeldingen (map)',
-'L_CONFIG_ADVANCED_DOCS_FOLDER'								=> 'Locatie documenten (map)',
+'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Locatie media (map)',
 'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Locatie artikels (map)',
 'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Locatie commentaar (map)',
 'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Locatie statische paginas (map)',
@@ -303,6 +307,7 @@ $LANG = array(
 'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Locatie van de plugins (map)',
 'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Locatie van de configuratie-bestanden (map)',
 'L_CONFIG_ADVANCED_UPDATE'									=> 'Aanpassingen doorvoeren',
+'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Locatie en de naam van aangepaste css-bestand van de administratie gebied (optioneel)',
 'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Basisconfiguratie',
 'L_CONFIG_BASE_SITE_TITLE'									=> 'Titel van de site',
 'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Ondertitel van de site',
@@ -436,7 +441,7 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Parameters',
 'L_MENU_PROFIL_TITLE'										=> 'Uw gebruikersprofiel beheren',
 'L_MENU_PROFIL'												=> 'Profiel',
-'L_WARNING_INSTALLATION_FILE'								=> '<p class="warning">het bestand install.php is nog aanwezig in de basismap van uw PluXml.<br />Om veiligheidsredenen raden wij u aan dit bestand te verwijderen of te hernoemen.</p>',
+'L_WARNING_INSTALLATION_FILE'								=> 'het bestand install.php is nog aanwezig in de basismap van uw PluXml.<br />Om veiligheidsredenen raden wij u aan dit bestand te verwijderen of te hernoemen.',
 'L_USER_UNKNOWN'											=> 'Onbekende gebruiker',
 'L_USER_LANG'												=> 'Gebruikte taal in adminstratief gedeelte',
 'L_USER_MAIL'												=> 'Emailadres',
