@@ -2,11 +2,15 @@
 
 $LANG = array(
 
+'L_MENU'													=> 'Menu',
 'L_UNKNOWN_ERROR'											=> 'Erro desconhecido',
 'L_CONFIRM_DELETE'											=> 'Potwierdź usunięcie ?',
 'L_SAVE_FILE'												=> 'Zapisz plik',
 'L_SAVE_FILE_SUCCESSFULLY'									=> 'Plik zapisany pomyślnie',
 'L_SAVE_FILE_ERROR'											=> 'Błąd podczas zapisywania pliku do',
+'L_DELETE'													=> 'Usunąć',
+'L_DELETE_FILE' 				    						=> 'Usuń plik',
+'L_DELETE_FOLDER'				   							=> 'Usuń folderu',
 'L_SAVE_SUCCESSFUL'											=> 'Grabação dos dados efectuada com sucesso',
 'L_SAVE_ERR'												=> 'Ocorreu um erro durante o processo de grabação dos dados',
 'L_NO_ENTRY'												=> 'Acesso refusado',
@@ -107,6 +111,8 @@ $LANG = array(
 'L_ARTICLE_TITLE_HTMLTAG'									=> 'Título conteúdo tag (opcional)',
 'L_ARTICLE_CHAPO_HIDE'										=> 'esconder',
 'L_ARTICLE_CHAPO_DISPLAY'									=> 'mostrar',
+'L_ARTICLE'													=> 'artykuł',
+'L_ARTICLE_ID'												=> 'Nome interno',
 'L_AUTH_PAGE_TITLE'											=> 'Página de identificação',
 'L_LOGOUT_SUCCESSFUL'										=> 'Foi correctamente deconectado',
 'L_LOGIN_PAGE'												=> 'Conexão á zona de administração ',
@@ -129,7 +135,6 @@ $LANG = array(
 'L_HIDE'													=> 'Esconder',
 'L_OPTIONS'													=> 'Opções',
 'L_FOR_SELECTION'											=> 'Para a selecção...',
-'L_DELETE'													=> 'Suprimir',
 'L_CAT_APPLY_BUTTON'										=> 'Alterar a lista das categorias',
 'L_CAT_UNKNOWN'												=> 'categoria desconhecida',
 'L_EDITCAT_PAGE_TITLE'										=> 'Edição das opções da categoria',
@@ -223,7 +228,7 @@ $LANG = array(
 'L_ALL_DRAFTS'												=> 'Rascunhos',
 'L_ALL_AWAITING_MODERATION'									=> 'Validação pendente',
 'L_MEDIAS_DELETE_FOLDER'									=> 'Suprimir a  pasta',
-'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Suprimir a pasta e o seu conteúdo ?',
+'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Suprimir a pasta %s e o seu conteúdo ?',
 'L_MEDIAS_NO_FILE'											=> 'Nenhum ficheiro',
 'L_MEDIAS_FILENAME'											=> 'Nome de ficheiro',
 'L_MEDIAS_ADD_FILE'											=> 'Adicionar o ficheiro',
@@ -275,7 +280,7 @@ $LANG = array(
 'L_CONFIG_VIEW_IMAGES'										=> 'Tamanho da imagem (largura x altura)',
 'L_CONFIG_VIEW_THUMBS'										=> 'Tamanhos das miniaturas (largura x altura)',
 'L_CONFIG_VIEW_HOMESTATIC'									=> 'Utilizar uma página stática como página de índice',
-'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> '<span class="alert">Atenção esta página está inactiva</span>',
+'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Atenção esta página está inactiva',
 'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Descarregue outros temas em <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
 'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'Numero de artigos/comentários exibidoss nops fluxos Rss',
 'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Mostrar sómente o chapéu dos artigos nos fluxos Rss',
@@ -286,16 +291,15 @@ $LANG = array(
 'L_CONFIG_HOMETEMPLATE'										=> 'Szablon strony głównej',
 'L_CONFIG_ADVANCED_DESC'									=> 'Configuração avançada',
 'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'Activar a re-escritura dos URLS',
-'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> '<span class="alert">Baczność .htaccess jest obecna w katalogu głównym PluXml. Poprzez umożliwienie przepisywania URL ten plik zostanie zmodyfikowany</span>',
+'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Baczność .htaccess jest obecna w katalogu głównym PluXml. Poprzez umożliwienie przepisywania URL ten plik zostanie zmodyfikowany',
 'L_CONFIG_ADVANCED_GZIP'									=> 'Activar a compressão GZIP',
 'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Permite de comprimir as páginas afim de economizar os dados transferidos entre o servidor e o seu computer, em consequência aumenta a carga do servidor ! Desactive se o sue web-site fôr muito visitado',
 'L_CONFIG_ADVANCED_CAPCHA'									=> 'Activar o capcha anti-spam',
 'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Chave de administração (URLS privadas)',
 'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Esvaziar o campo afim de regenerar a chave novamente',
-'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Utilizar uma pasta imagens e documentos diferente para cada utilizador',
+'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Utilizar uma pasta medias diferente para cada utilizador',
 'L_HELP_SLASH_END'											=> 'Não esquecêr o flash "/" no fim',
-'L_CONFIG_ADVANCED_PICS_FOLDER'								=> 'Położenie obrazów (katalog)',
-'L_CONFIG_ADVANCED_DOCS_FOLDER'								=> 'Lokalizacja dokument (katalog)',
+'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Lokalizacja mediów (folder)',
 'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Lokalizacja elementów (katalog)',
 'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Lokalizacja komentarzy (katalog)',
 'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Lokalizacja statycznych stron (katalog)',
@@ -303,6 +307,7 @@ $LANG = array(
 'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Lokalizacja plugins (katalog)',
 'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Lokalizacja plików konfiguracyjnych (katalog)',
 'L_CONFIG_ADVANCED_UPDATE'									=> 'Alterar a configura avançada',
+'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Lokalizacja i nazwa pliku css na zlecenie administracji obszaru (opcjonalnie)',
 'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Configuração de base',
 'L_CONFIG_BASE_SITE_TITLE'									=> 'Titúlo do web-site',
 'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Sob-titúlo/descrição do web-site',
@@ -436,7 +441,7 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Parâmetros',
 'L_MENU_PROFIL_TITLE'										=> 'Gerir o perfil do utilizador',
 'L_MENU_PROFIL'												=> 'Perfil',
-'L_WARNING_INSTALLATION_FILE'								=> '<p class="warning">O ficheiro install.php está presente na raíz de PluXml.<br />Por razões de segurança apague (delete) este ficheiro.</p>',
+'L_WARNING_INSTALLATION_FILE'								=> 'O ficheiro install.php está presente na raíz de PluXml.<br />Por razões de segurança apague (delete) este ficheiro.',
 'L_USER_UNKNOWN'											=> 'Utilizador desconhecido',
 'L_USER_LANG'												=> 'Idioma utilizado na administração',
 'L_USER_MAIL'												=> 'Enderêco e-mail',
