@@ -2,11 +2,15 @@
 
 $LANG = array(
 
+'L_MENU'													=> 'Meniu',
 'L_UNKNOWN_ERROR'											=> 'Eroare necunoscută',
 'L_CONFIRM_DELETE'											=> 'Confirmați ștergerea ?',
 'L_SAVE_FILE'												=> 'Salvați fișierul',
 'L_SAVE_FILE_SUCCESSFULLY'									=> 'Fișier salvat cu succes',
 'L_SAVE_FILE_ERROR'											=> 'Salvarea fișierului de eroare',
+'L_DELETE'													=> 'Şterge',
+'L_DELETE_FILE' 				    						=> 'Ștergeți fișier',
+'L_DELETE_FOLDER'				   							=> 'Ștergeți dosar',
 'L_SAVE_SUCCESSFUL'											=> 'Înregistrarea a fost efectuata cu succes',
 'L_SAVE_ERR'												=> 'Eroare la înregistrare ',
 'L_NO_ENTRY'												=> 'Acces refuzat',
@@ -107,6 +111,8 @@ $LANG = array(
 'L_ARTICLE_TITLE_HTMLTAG'									=> 'Conţinutul tag-ul titlu (opţional)',
 'L_ARTICLE_CHAPO_HIDE'										=> 'ascunde',
 'L_ARTICLE_CHAPO_DISPLAY'									=> 'afişa',
+'L_ARTICLE'													=> 'articol',
+'L_ARTICLE_ID'												=> 'ID',
 'L_AUTH_PAGE_TITLE'											=> 'Pagina de autentificare',
 'L_LOGOUT_SUCCESSFUL'										=> 'Vati deconectat cu succes',
 'L_LOGIN_PAGE'												=> 'Conectare in zona de administrare ',
@@ -129,7 +135,6 @@ $LANG = array(
 'L_HIDE'													=> 'Ascunde',
 'L_OPTIONS'													=> 'Opţiuni',
 'L_FOR_SELECTION'											=> 'Alegeţi obţiunea...',
-'L_DELETE'													=> 'Şterge',
 'L_CAT_APPLY_BUTTON'										=> 'Modifică lista de categorii',
 'L_CAT_UNKNOWN'												=> 'Categorie necunoscuta',
 'L_EDITCAT_PAGE_TITLE'										=> 'Editarea categoriei',
@@ -223,7 +228,7 @@ $LANG = array(
 'L_ALL_DRAFTS'												=> 'Schiţe',
 'L_ALL_AWAITING_MODERATION'									=> 'Până la validare',
 'L_MEDIAS_DELETE_FOLDER'									=> 'Ştergeţi Directoriu',
-'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Sunteti sigur ca doriti sa stergeţi directoriul şi conţinutul lui ?',
+'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Sunteti sigur ca doriti sa stergeţi directoriul şi conţinutul lui %s ?',
 'L_MEDIAS_NO_FILE'											=> 'Nici un fişier',
 'L_MEDIAS_FILENAME'											=> 'Filename',
 'L_MEDIAS_ADD_FILE'											=> 'Adăugaţi fişiere',
@@ -275,7 +280,7 @@ $LANG = array(
 'L_CONFIG_VIEW_IMAGES'										=> 'Dimensiune imagine (latime x inaltime)',
 'L_CONFIG_VIEW_THUMBS'										=> 'Thumbnail dimensiuni (latime x inaltime)',
 'L_CONFIG_VIEW_HOMESTATIC'									=> 'Utilizaţi o pagină statică ca Home-page',
-'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> '<span class="alert">Atenţie, această pagină este inactivă</span>',
+'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Atenţie, această pagină este inactivă',
 'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Descarcă alte teme <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
 'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'Numărul de articole  şi comentarii postate pe fluxul Rss',
 'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Vezi Headerul în articolele RSS',
@@ -286,16 +291,15 @@ $LANG = array(
 'L_CONFIG_HOMETEMPLATE'										=> 'Format din pagina de start',
 'L_CONFIG_ADVANCED_DESC'									=> 'Avansate de configurare',
 'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'Permite rescrierea url-uri',
-'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> '<span class="alert">Atenţie într-un fişier. Htaccess este deja prezent la rădăcina PluXml dumneavoastră. Prin activarea rescrierea dosarul \ url va fi modificat</span>',
+'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Atenţie într-un fişier. Htaccess este deja prezent la rădăcina PluXml dumneavoastră. Prin activarea rescrierea dosarul \ url va fi modificat',
 'L_CONFIG_ADVANCED_GZIP'									=> 'Activeaza compresia GZIP',
 'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Comprimă paginile pentru a salva de lăţime de bandă, însă acest lucru poate creşte sarcina procesorului',
 'L_CONFIG_ADVANCED_CAPCHA'									=> 'Activeaza capcha anti-spam',
 'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Cheie de administrare (URL-uri private)',
 'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Clar acest domeniu pentru a regenera cheie',
-'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Folosind imagini şi documente dosar pentru fiecare utilizator diferite',
+'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Folosind medias dosar pentru fiecare utilizator diferite',
 'L_HELP_SLASH_END'											=> 'Nu uita slash de final',
-'L_CONFIG_ADVANCED_PICS_FOLDER'								=> 'Localizare imagini (dosar)',
-'L_CONFIG_ADVANCED_DOCS_FOLDER'								=> 'Document locaţie (dosar)',
+'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Locul de amplasare Media (director)',
 'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Locul de amplasare de elemente (dosar)',
 'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Locul de amplasare Review (dosar)',
 'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Locul de amplasare de pagini statice (dosar)',
@@ -303,6 +307,7 @@ $LANG = array(
 'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Locul de amplasare a plugin-uri (dosar)',
 'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Locul de fişiere de configurare (dosar)',
 'L_CONFIG_ADVANCED_UPDATE'									=> 'Editare configuraţie avansată',
+'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Locația și numele de fișier css personalizat buna administrare (opțional)',
 'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Configurarea bazei',
 'L_CONFIG_BASE_SITE_TITLE'									=> 'Denumirea sitului',
 'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Descriere sitului',
@@ -436,7 +441,7 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Setări',
 'L_MENU_PROFIL_TITLE'										=> 'Gestionează profilul',
 'L_MENU_PROFIL'												=> 'Profil',
-'L_WARNING_INSTALLATION_FILE'								=> '<p class="warning">Fişierul install.php încă se află în rădăcina  sit-ului <br /> PluXml. Din motive de securitate, se recomandă să-l ştergeţi.</p>',
+'L_WARNING_INSTALLATION_FILE'								=> 'Fişierul install.php încă se află în rădăcina  sit-ului <br /> PluXml. Din motive de securitate, se recomandă să-l ştergeţi.',
 'L_USER_UNKNOWN'											=> 'Utilizator necunoscut',
 'L_USER_LANG'												=> 'Limba utilizată ',
 'L_USER_MAIL'												=> 'Adresa de email',
