@@ -1,24 +1,22 @@
 <?php include(dirname(__FILE__).'/header.php'); ?>
 
-<section>
+	<main class="main grid" role="main">
 
-	<div id="container">
-
-		<div class="width-sidebar">
+		<section class="col sml-12 med-8">
 
 			<?php while($plxShow->plxMotor->plxRecord_arts->loop()): ?>
 
-			<article role="article" id="post-<?php echo $plxShow->artId(); ?>">
+			<article class="article" role="article" id="post-<?php echo $plxShow->artId(); ?>">
 
 				<header>
 					<h1>
 						<?php $plxShow->artTitle('link'); ?>
 					</h1>
-					<p>
+					<small>
 						<?php $plxShow->lang('WRITTEN_BY'); ?> <?php $plxShow->artAuthor() ?> -
 						<time datetime="<?php $plxShow->artDate('#num_year(4)-#num_month-#num_day'); ?>"><?php $plxShow->artDate('#num_day #month #num_year(4)'); ?></time> -
 						<?php $plxShow->artNbCom(); ?>
-					</p>
+					</small>
 				</header>
 
 				<section>
@@ -26,30 +24,28 @@
 				</section>
 
 				<footer>
-					<p>
-						<?php $plxShow->lang('CLASSIFIED_IN') ?> : <?php $plxShow->artCat(); ?> -
-						<?php $plxShow->lang('TAGS') ?> : <?php $plxShow->artTags(); ?>
-					</p>
+					<small>
+						<?php $plxShow->lang('CLASSIFIED_IN') ?> : <?php $plxShow->artCat() ?> - 
+						<?php $plxShow->lang('TAGS') ?> : <?php $plxShow->artTags() ?>
+					</small>
 				</footer>
 
 			</article>
 
 			<?php endwhile; ?>
 
-			<div id="pagination">
+			<nav class="pagination text-center">
 				<?php $plxShow->pagination(); ?>
-			</div>
+			</nav>
 
-			<div class="rss">
+			<span>
 				<?php $plxShow->artFeed('rss',$plxShow->catId()); ?>
-			</div>
+			</span>
 
-		</div>
+		</section>
 
 		<?php include(dirname(__FILE__).'/sidebar.php'); ?>
 
-	</div>
-
-</section>
+	</main>
 
 <?php include(dirname(__FILE__).'/footer.php'); ?>
