@@ -1,28 +1,27 @@
 <?php include(dirname(__FILE__).'/header.php'); ?>
 
-<section>
+	<main class="main grid" role="main">
 
-	<div id="container">
+		<section class="col sml-12 med-8">
 
-		<div class="width-sidebar">
-
-			<p class="directory">
-				<strong><?php $plxShow->tagName(); ?></strong>
-			</p>
+			<ul class="repertory menu breadcrumb">
+				<li><a href="<?php $plxShow->racine() ?>"><?php $plxShow->lang('HOME'); ?></a></li>
+				<li><?php $plxShow->tagName(); ?></li>	
+			</ul>
 
 			<?php while($plxShow->plxMotor->plxRecord_arts->loop()): ?>
 
-			<article role="article" id="post-<?php echo $plxShow->artId(); ?>">
+			<article class="article" role="article" id="post-<?php echo $plxShow->artId(); ?>">
 
 				<header>
 					<h1>
 						<?php $plxShow->artTitle('link'); ?>
 					</h1>
-					<p>
+					<small>
 						<?php $plxShow->lang('WRITTEN_BY'); ?> <?php $plxShow->artAuthor() ?> -
 						<time datetime="<?php $plxShow->artDate('#num_year(4)-#num_month-#num_day'); ?>"><?php $plxShow->artDate('#num_day #month #num_year(4)'); ?></time> -
 						<?php $plxShow->artNbCom(); ?>
-					</p>
+					</small>
 				</header>
 
 				<section>
@@ -30,30 +29,28 @@
 				</section>
 
 				<footer>
-					<p>
-						<?php $plxShow->lang('CLASSIFIED_IN') ?> : <?php $plxShow->artCat(); ?> -
-						<?php $plxShow->lang('TAGS') ?> : <?php $plxShow->artTags(); ?>
-					</p>
+					<small>
+						<?php $plxShow->lang('CLASSIFIED_IN') ?> : <?php $plxShow->artCat() ?> - 
+						<?php $plxShow->lang('TAGS') ?> : <?php $plxShow->artTags() ?>
+					</small>
 				</footer>
 
 			</article>
 
 			<?php endwhile; ?>
 
-			<div id="pagination">
+			<nav class="pagination text-center">
 				<?php $plxShow->pagination(); ?>
-			</div>
+			</nav>
 
-			<div class="rss">
+			<span>
 				<?php $plxShow->tagFeed() ?>
-			</div>
+			</span>
 
-		</div>
+		</section>
 
 		<?php include(dirname(__FILE__).'/sidebar.php'); ?>
 
-	</div>
-
-</section>
+	</main>
 
 <?php include(dirname(__FILE__).'/footer.php'); ?>
